@@ -25,8 +25,11 @@ scenario_list <- list(
   )
   ,
   list(
-    scores = rep(rnorm(20), each = 5),
-    positives = rep(rbinom(20, 1, 0.5), each = 5),
+    scores = rep(c(-0.262, -0.069, -0.379, 2.582, 0.13,
+                   -0.713, 0.638, 0.202, -0.07, -0.092,
+                   0.449, -1.064, -1.162, 1.649, -2.062,
+                   0.013, -1.088, 0.271, 1.008, -2.074), each = 5),
+    positives = rep(c(0, 1, 1, 1, 0, 1, 1, 0, 0, 1, 1, 0, 0, 0, 1, 0, 1, 0, 0, 1), each = 5),
     totals = 1
   )
 )
